# PeptideMatchOpenApi20.PeptideMatchAPI20Api

All URIs are relative to *http://research.bioinformatics.udel.edu/peptidematchapi2*

Method | HTTP request | Description
------------- | ------------- | -------------
[**matchGetGet**](PeptideMatchAPI20Api.md#matchGetGet) | **GET** /match_get | Do peptide match using GET method.
[**matchPostPost**](PeptideMatchAPI20Api.md#matchPostPost) | **POST** /match_post | Do peptide match using POST method.


<a name="matchGetGet"></a>
# **matchGetGet**
> Report matchGetGet(peptides, opts)

Do peptide match using GET method.

Retrieve UniProtKB protein sequences that would exactly match to the query peptides using GET method.

### Example
```javascript
var PeptideMatchOpenApi20 = require('peptide_match_open_api_20');

var apiInstance = new PeptideMatchOpenApi20.PeptideMatchAPI20Api();

var peptides = "AAVEEGIVLGGGCALLR,SVQYDDVPEYK"; // String | A list of comma-separated peptide sequences (up to 100). Each sequence consists of 3 or more amino acids.

var opts = { 
  'taxonids': "9606,10090", // String | A list fo comma-separated NCBI taxonomy IDs.
  'swissprot': true, // Boolean | Only search SwissProt protein sequences.
  'isoform': true, // Boolean | Include isforms.
  'uniref100': false, // Boolean | Only search UniRef100 protein sequences.
  'leqi': false, // Boolean | Treat Leucine (L) and Isoleucine (I) equivalent.
  'offset': 0, // Number | Off set, page starting point, with default value 0.
  'size': 100 // Number | Page size with default value 100. When page size is -1, it returns all records and offset will be ignored.
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.matchGetGet(peptides, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **peptides** | **String**| A list of comma-separated peptide sequences (up to 100). Each sequence consists of 3 or more amino acids. | [default to AAVEEGIVLGGGCALLR,SVQYDDVPEYK]
 **taxonids** | **String**| A list fo comma-separated NCBI taxonomy IDs. | [optional] [default to 9606,10090]
 **swissprot** | **Boolean**| Only search SwissProt protein sequences. | [optional] [default to true]
 **isoform** | **Boolean**| Include isforms. | [optional] [default to true]
 **uniref100** | **Boolean**| Only search UniRef100 protein sequences. | [optional] [default to false]
 **leqi** | **Boolean**| Treat Leucine (L) and Isoleucine (I) equivalent. | [optional] [default to false]
 **offset** | **Number**| Off set, page starting point, with default value 0. | [optional] [default to 0]
 **size** | **Number**| Page size with default value 100. When page size is -1, it returns all records and offset will be ignored. | [optional] [default to 100]

### Return type

[**Report**](Report.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json, application/xml, text/x-fasta, text/tab-separated-values

<a name="matchPostPost"></a>
# **matchPostPost**
> Report matchPostPost(peptides, opts)

Do peptide match using POST method.

Retrieve UniProtKB protein sequences that would exactly match to the query peptides using POST method.

### Example
```javascript
var PeptideMatchOpenApi20 = require('peptide_match_open_api_20');

var apiInstance = new PeptideMatchOpenApi20.PeptideMatchAPI20Api();

var peptides = "AAVEEGIVLGGGCALLR,SVQYDDVPEYK"; // String | A list of comma-separated peptide sequences (up to 100). Each sequence consists of 3 or more amino acids.

var opts = { 
  'taxonids': "9606,10090", // String | A list fo comma-separated NCBI taxonomy IDs.
  'swissprot': true, // Boolean | Only search SwissProt protein sequences.
  'isoform': true, // Boolean | Include isoforms.
  'uniref100': false, // Boolean | Only search UniRef100 protein sequences.
  'leqi': false, // Boolean | Treat Leucine (L) and Isoleucine (I) equivalent.
  'offset': 0, // Number | Off set, page starting point, with default value 0.
  'size': 100 // Number | Page size with default value 100. When page size is -1, it returns all records and offset will be ignored.
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.matchPostPost(peptides, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **peptides** | **String**| A list of comma-separated peptide sequences (up to 100). Each sequence consists of 3 or more amino acids. | [default to AAVEEGIVLGGGCALLR,SVQYDDVPEYK]
 **taxonids** | **String**| A list fo comma-separated NCBI taxonomy IDs. | [optional] [default to 9606,10090]
 **swissprot** | **Boolean**| Only search SwissProt protein sequences. | [optional] [default to true]
 **isoform** | **Boolean**| Include isoforms. | [optional] [default to true]
 **uniref100** | **Boolean**| Only search UniRef100 protein sequences. | [optional] [default to false]
 **leqi** | **Boolean**| Treat Leucine (L) and Isoleucine (I) equivalent. | [optional] [default to false]
 **offset** | **Number**| Off set, page starting point, with default value 0. | [optional] [default to 0]
 **size** | **Number**| Page size with default value 100. When page size is -1, it returns all records and offset will be ignored. | [optional] [default to 100]

### Return type

[**Report**](Report.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml, text/x-fasta, text/tab-separated-values

